Learn R Programming

idcnrba (version 1.1.0)

idcnrba-package: idcnrba: Interactive Application for Analyzing Representativeness and Nonresponse Bias

Description

logo

Provides access to the Idea Data Center (IDC) application for conducting nonresponse bias analysis (NRBA). The IDC NRBA app is an interactive, browser-based Shiny application that can be used to analyze survey data with respect to response rates, representativeness, and nonresponse bias. This app provides a user-friendly interface to statistical methods implemented by the 'nrba' package. Krenzke, Van de Kerckhove, and Mohadjer (2005) http://www.asasrms.org/Proceedings/y2005/files/JSM2005-000572.pdf and Lohr and Riddles (2016) https://www150.statcan.gc.ca/n1/en/pub/12-001-x/2016002/article/14677-eng.pdf?st=q7PyNsGR provide an overview of the statistical methods implemented in the application.

Arguments

Author

Maintainer: Ben Schneider BenjaminSchneider@westat.com (ORCID)

Authors:

Other contributors:

  • Westat [copyright holder]